@@ -8,4 +8,6 @@ from .ktransit import LCModel
 from .ktransit import give_me_earth
 from .fittransit import FitTransit
 from .fittransit import FitTransitWiener
+from .fittransit import FitTransitWienerL
+from .fittransit import FitTransitWienerLG
 from .fittransit import plot_results
